@@ -5,12 +5,12 @@ import logging
 import threading
 import uuid
 from asyncio import Lock
-from typing import Optional
+from typing import Optional, Type
 from urllib.parse import urlparse
 
 import paho.mqtt.client as mqtt
 
-from .api import COMMANDS_SECURED, KEEPALIVE, RoborockClient, md5hex
+from .api import COMMANDS_SECURED, KEEPALIVE, RT, RoborockClient, md5hex
 from .containers import DeviceData, UserData
 from .exceptions import CommandVacuumError, RoborockException, VacuumError
 from .protocol import MessageParser, Utils
@@ -119,14 +119,14 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
         return rc == mqtt.MQTT_ERR_SUCCESS
 
     def sync_connect(self) -> bool:
-        self.sync_start_loop()
-        if not self.is_connected():
+        should_connect = not self.is_connected()
+        if should_connect:
             if self._mqtt_port is None or self._mqtt_host is None:
                 raise RoborockException("Mqtt information was not entered. Cannot connect.")
             _LOGGER.info("Connecting to mqtt")
             super().connect(host=self._mqtt_host, port=self._mqtt_port, keepalive=KEEPALIVE)
-            return True
-        return False
+        self.sync_start_loop()
+        return should_connect
 
     async def async_disconnect(self) -> None:
         async with self._mutex:
@@ -149,7 +149,12 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
         if info.rc != mqtt.MQTT_ERR_SUCCESS:
             raise RoborockException(f"Failed to publish ({mqtt.error_string(info.rc)})")
 
-    async def send_command(self, method: RoborockCommand, params: Optional[list | dict] = None):
+    async def send_command(
+        self,
+        method: RoborockCommand,
+        params: Optional[list | dict] = None,
+        return_type: Optional[Type[RT]] = None,
+    ) -> RT:
         await self.validate_connection()
         request_id, timestamp, payload = super()._get_payload(method, params, True)
         _LOGGER.debug(f"id={request_id} Requesting method {method} with {params}")
@@ -160,17 +165,16 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
         msg = MessageParser.build(roborock_message, local_key, False)
         self._send_msg_raw(msg)
         (response, err) = await self._async_response(request_id, response_protocol)
+        self._diagnostic_data[method.name] = {"params": params, "response": response, "error": err}
         if err:
             raise CommandVacuumError(method, err) from err
         if response_protocol == 301:
             _LOGGER.debug(f"id={request_id} Response from {method}: {len(response)} bytes")
         else:
             _LOGGER.debug(f"id={request_id} Response from {method}: {response}")
+        if return_type:
+            return return_type.from_dict(response)
         return response
 
     async def get_map_v1(self):
-        try:
-            return await self.send_command(RoborockCommand.GET_MAP_V1)
-        except RoborockException as e:
-            _LOGGER.error(e)
-        return None
+        return await self.send_command(RoborockCommand.GET_MAP_V1)
